@@ -5,19 +5,23 @@
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
 ///
-/// # Example
+/// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
 /// assert!(true);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert!(false);
-/// //-> panic!("assertion failed: false")
+/// # let result = panic::catch_unwind(|| {
+/// assert!(false);
+/// //-> panic!
+/// // assertion failed: false
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: false";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -32,34 +36,28 @@ mod tests {
     fn test_assert_x_arity_2_success() {
         let a = true;
         let x = assert!(a);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
     #[should_panic (expected = "assertion failed: a")]
     fn test_assert_x_arity_2_failure() {
         let a = false;
-        let _ = assert!(a);
+        let _x = assert!(a);
     }
 
     #[test]
     fn test_assert_x_arity_3_success() {
         let a = true;
         let x = assert!(a, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
     #[should_panic (expected = "message")]
     fn test_assert_x_arity_3_failure() {
         let a = false;
-        let _ = assert!(a, "message");
+        let _x = assert!(a, "message");
     }
 
 }
