@@ -1,6 +1,6 @@
-/// Assert two values are equal.
+/// Assert a value is equal to anoter.
 ///
-/// * When true, return `Ok(true)`.
+/// * When true, return `Ok(())`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -8,17 +8,22 @@
 /// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
 /// assert_eq!(1, 1);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_eq!(1, 2);
-/// //-> panic!("assertion failed: `(left == right)`\n  left: `1`,\n right: `2`")
-/// # }
+/// # let result = panic::catch_unwind(|| {
+/// assert_eq!(1, 2);
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `(left == right)`\n  left: `1`,\n right: `2`";
+/// # assert_eq!(err, );
+/// //-> panic!("…")
+/// // assertion failed: `(left == right)`
+/// //   left: `1`,
+/// //  right: `2`/// # }
 /// ```
 ///
 /// This macro has a second form where a custom message can be provided.
@@ -33,10 +38,7 @@ mod tests {
         let a = 1;
         let b = 1;
         let x = assert_eq!(a, b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
@@ -52,10 +54,7 @@ mod tests {
         let a = 1;
         let b = 1;
         let x = assert_eq!(a, b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
