@@ -1,6 +1,6 @@
-/// Assert one value is less than or equal to another value.
+/// Assert a value is less than or equal to another.
 ///
-/// * When true, return `Ok(true)`.
+/// * When true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -8,16 +8,22 @@
 /// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
 /// assert_io_le!(1, 2);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_io_le!(2, 1);
-/// //-> panic!("assertion failed: `assert_io_le(left, right)`\n  left: `2`,\n right: `1`")
+/// # let result = panic::catch_unwind(|| {
+/// assert_io_le!(2, 1);
+/// //-> panic!
+/// // assertion failed: `assert_io_le!(left, right)`
+/// //   left: `2`,
+/// //  right: `1`
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `assert_io_le!(left, right)`\n  left: `2`,\n right: `1`";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -30,7 +36,7 @@ macro_rules! assert_io_le {
                 if (left_val <= right_val) {
                     ()
                 } else {
-                    panic!("assertion failed: `assert_io_le(left, right)`\n  left: `{:?}`\n right: `{:?}`", $left, $right);
+                    panic!("assertion failed: `assert_io_le!(left, right)`\n  left: `{:?}`,\n right: `{:?}`", $left, $right);
                 }
             }
         }
@@ -56,14 +62,11 @@ mod tests {
         let a = 1;
         let b = 2;
         let x = assert_io_le!(a, b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
-    #[should_panic (expected = "assertion failed: `assert_io_le(left, right)`\n  left: `2`\n right: `1`")]
+    #[should_panic (expected = "assertion failed: `assert_io_le!(left, right)`\n  left: `2`,\n right: `1`")]
     fn test_assert_io_le_x_arity_2_failure() {
         let a = 2;
         let b = 1;
@@ -75,10 +78,7 @@ mod tests {
         let a = 1;
         let b = 2;
         let x = assert_io_le!(a, b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
