@@ -1,4 +1,4 @@
-/// Assert one value is less than another value.
+/// Assert a value is less than another.
 ///
 /// * When true, return `()`.
 ///
@@ -8,16 +8,22 @@
 /// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
 /// assert_lt!(1, 2);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_lt!(2, 1);
-/// //-> panic!("assertion failed: `assert_lt(left, right)`\n  left: `2`\n right: `1`")
+/// # let result = panic::catch_unwind(|| {
+/// assert_lt!(2, 1);
+/// //-> panic!
+/// // assertion failed: `assert_lt!(left, right)`
+/// //   left: `2`,
+/// //  right: `1`
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `assert_lt!(left, right)`\n  left: `2`,\n right: `1`";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -30,7 +36,7 @@ macro_rules! assert_lt {
                 if (left_val < right_val) {
                     ()
                 } else {
-                    panic!("assertion failed: `assert_lt(left, right)`\n  left: `{:?}`\n right: `{:?}`", $left, $right);
+                    panic!("assertion failed: `assert_lt!(left, right)`\n  left: `{:?}`,\n right: `{:?}`", $left, $right);
                 }
             }
         }
@@ -56,18 +62,15 @@ mod tests {
         let a = 1;
         let b = 2;
         let x = assert_lt!(a, b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
-    #[should_panic (expected = "assertion failed: `assert_lt(left, right)`\n  left: `2`\n right: `1`")]
+    #[should_panic (expected = "assertion failed: `assert_lt!(left, right)`\n  left: `2`,\n right: `1`")]
     fn test_assert_lt_x_arity_2_failure() {
         let a = 2;
         let b = 1;
-        let _ = assert_lt!(a, b);
+        let _x = assert_lt!(a, b);
     }
 
     #[test]
@@ -75,10 +78,7 @@ mod tests {
         let a = 1;
         let b = 2;
         let x = assert_lt!(a, b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
@@ -86,7 +86,7 @@ mod tests {
     fn test_assert_lt_x_arity_3_failure() {
         let a = 2;
         let b = 1;
-        let _ = assert_lt!(a, b, "message");
+        let _x = assert_lt!(a, b, "message");
     }
 
 }
