@@ -1,7 +1,7 @@
 use ::assertables::*;
 
-fn foo_assume(a: i32, b: i32) -> Result<i32, String> {
-    assume_lt!(a, b)?;
+fn foo_assure(a: i32, b: i32) -> Result<i32, String> {
+    assertable_lt!(a, b)?;
     Ok(a)
 }
 
@@ -10,7 +10,7 @@ fn foo_assume(a: i32, b: i32) -> Result<i32, String> {
 fn test_x_success() {
     let a = 1;
     let b = 2;
-    let x = foo_assume(a, b);
+    let x = foo_assure(a, b);
     assert_eq!(
         x.unwrap(),
         a
@@ -21,9 +21,9 @@ fn test_x_success() {
 fn test_x_failure() {
     let a = 2;
     let b = 1;
-    let x = foo_assume(a, b);
+    let x = foo_assure(a, b);
     assert_eq!(
         x.unwrap_err(),
-        "assumption failed: `assume_lt(left, right)`\n  left: `2`\n right: `1`"
+        "assertable failed: `assertable_lt!(left, right)`\n  left: `2`,\n right: `1`"
     );
 }
